/***************************************************************************
 * Copyright 2001-2003 The eXo Platform SARL         All rights reserved.  *
 * Please look at license.txt in info directory for more license detail.   *
 **************************************************************************/

import java.util.HashMap;
import java.util.Map;

import javax.jcr.Node;
import javax.jcr.Session;

import org.apache.commons.lang.StringUtils;
import org.exoplatform.services.cms.JcrInputProperty;
import org.exoplatform.services.cms.actions.ActionServiceContainer;
import org.exoplatform.services.jcr.RepositoryService;
import org.exoplatform.container.PortalContainer;
import org.exoplatform.services.cms.scripts.CmsScript;
import org.exoplatform.services.cms.CmsConfigurationService ;

public class PostNewsSaveInterceptor implements CmsScript {
  
  public PostNewsSaveInterceptor() {
  }
  
  public void execute(Object context) {
    if(context == null) return ;
    String path = (String) context;       
    println("Post node save interceptor, created node: "+ path);
    Node node ;
    String[] splittedContent = StringUtils.split(path, ":");
    PortalContainer container= PortalContainer.getInstance();
    RepositoryService repService = (RepositoryService) container.getComponentInstanceOfType(RepositoryService.class);
    if(splittedContent.length > 1) {
      Session session = repService.getRepository().login(splittedContent[0]);
      node = (Node) session.getItem(splittedContent[1]);
    } else {
      CmsConfigurationService cmsService = (CmsConfigurationService) container.getComponentInstanceOfType(CmsConfigurationService.class);
      Session session = repService.getRepository().login(cmsService.getWorkspace());
      node = (Node) session.getItem(path);
    }
    
    ActionServiceContainer actionsServiceContainer = (ActionServiceContainer) container.getComponentInstanceOfType(ActionServiceContainer.class);
        
    Map mappings = new HashMap();
         
    JcrInputProperty nodeTypeInputProperty = new JcrInputProperty();
    nodeTypeInputProperty.setJcrPath("/node");
    nodeTypeInputProperty.setMixintype("exo:move");
    nodeTypeInputProperty.setValue("validation");
    mappings.put("/node", nodeTypeInputProperty);
       
    JcrInputProperty nameInputProperty = new JcrInputProperty();
    nameInputProperty.setJcrPath("/node/exo:name");
    nameInputProperty.setValue("validation");
    mappings.put("/node/exo:name", nameInputProperty);        
        
    JcrInputProperty lifeCycleInputProperty = new JcrInputProperty();
    lifeCycleInputProperty.setJcrPath("/node/exo:lifecyclePhase");
    lifeCycleInputProperty.setValue("read"); 
    mappings.put("/node/exo:lifecyclePhase", lifeCycleInputProperty);
        
    JcrInputProperty descriptionInputProperty = new JcrInputProperty();
    descriptionInputProperty.setJcrPath("/node/exo:description");
    descriptionInputProperty.setValue("validate and copy node to /site/articles"); 
    mappings.put("/node/exo:description", descriptionInputProperty);         
        
    JcrInputProperty validatorInputProperty = new JcrInputProperty();
    validatorInputProperty.setJcrPath("/node/exo:validator");
    validatorInputProperty.setValue("member:/employees"); 
    mappings.put("/node/exo:validator", validatorInputProperty);   

    JcrInputProperty destWorkspaceInputProperty = new JcrInputProperty();
    destWorkspaceInputProperty.setJcrPath("/node/exo:destWorkspace");
    destWorkspaceInputProperty.setValue("production"); 
    mappings.put("/node/exo:destWorkspace", destWorkspaceInputProperty);  

    JcrInputProperty destPathInputProperty = new JcrInputProperty();
    destPathInputProperty.setJcrPath("/node/exo:destPath");
    destPathInputProperty.setValue("/site/news"); 
    mappings.put("/node/exo:destPath", destPathInputProperty);      
                                     
    actionsServiceContainer.addAction(node, "exo:workflowAction", mappings);
  }

  public void setParams(String[] params) {}

}
